TargetValueTermination<T> class

A TargetValueTermination is condtion that terminate the evolution engine after reach specific fitness value.

Implemented types

Constructors

TargetValueTermination(double value)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldTerminate(PopulationData<T> data) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited