SwapMutation<T> class
A SwapMutation is mutation operator applied to chromosomes of Iterable genes.
The mutation is done be swap tow elements randomlly in chromosome.
Constructors
- SwapMutation({required double probability})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- probability → double
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
Population< Iterable< population, Random rnd) → Population<T> >Iterable< T> > -
inherited
-
mute(
Iterable< T> chromosome, Random rnd) → Iterable<T> -
define a way that the chromosome data (genes) will be altered.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited